==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/admanager/InteractionAdManager.java <==
package com.yifan.yf_ads.admanager;

import android.app.Activity;
import android.view.ViewGroup;

import com.yfanads.android.YFAdsManager;
import com.yfanads.android.core.inter.YFAdInterstitialAds;
import com.yfanads.android.core.inter.YFInterstitialListener;
import com.yfanads.android.model.YFAdError;
import com.yifan.yf_ads.utils.Constants;
import com.yifan.yf_ads.utils.FLog;

import org.json.JSONException;
import org.json.JSONObject;

import io.flutter.plugin.common.EventChannel;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/25 10:14
 **/
public class InteractionAdManager extends CommonAdManager {

    private static final String TAG = "InteractionAdManager";


    private YFAdInterstitialAds easyInterstitial;

    public InteractionAdManager(Activity context) {
        super(context, Constants.AD_TYPE_INTERACTION);
    }

    public void requestInteractAD(String posId, EventChannel.EventSink eventSink) {
        if (!isSDKInit(TAG)) {
            return;
        }

        easyInterstitial = new YFAdInterstitialAds(activity, new YFInterstitialListener() {
            @Override
            public void onAdSuccess() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdSuccess");
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                showAd(activity);
            }

            @Override
            public void onAdExposure() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdShow");
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }

            @Override
            public void onAdClicked() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdClicked");
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }

            @Override
            public void onAdClosed() {
                FLog.i(TAG, "onAdClosed");
                callAdClose();
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdClosed");
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                destroy();
            }

            @Override
            public void onAdFailed(YFAdError yfAdError) {
                FLog.e(TAG, "onFailed, requestId: " + yfAdError.code + ", errMsg: " + yfAdError.msg);
                callAdFail(yfAdError.msg);
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onFailed");
                    jsonObject.put(Constants.KEY_ERROR, yfAdError.msg);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        });
        easyInterstitial.loadOnly(posId);
    }

    public void destroy() {
        if (easyInterstitial != null) {
            easyInterstitial.destroy();
        }
    }

    public void showAd(Activity activity) {
        if (easyInterstitial != null && activity != null) {
            easyInterstitial.showAds(activity);
        }
    }

}

==> 0.0.10.tar.gz: android/src/main/java/com/yifan/yf_ads/admanager/InteractionAdManager.java <==
package com.yifan.yf_ads.admanager;

import android.app.Activity;
import android.view.ViewGroup;

import com.yfanads.android.YFAdsManager;
import com.yfanads.android.core.inter.YFAdInterstitialAds;
import com.yfanads.android.core.inter.YFInterstitialListener;
import com.yfanads.android.model.YFAdError;
import com.yfanads.android.utils.InitUtils;
import com.yfanads.android.utils.YFLog;
import com.yifan.yf_ads.bean.InteractionBean;
import com.yifan.yf_ads.utils.Constants;
import com.yifan.yf_ads.utils.FLog;

import org.json.JSONException;
import org.json.JSONObject;

import io.flutter.plugin.common.EventChannel;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/25 10:14
 **/
public class InteractionAdManager extends CommonAdManager {

    private static final String TAG = "InteractionAdManager";


    private YFAdInterstitialAds easyInterstitial;

    // load 状态：0 未请求， 1正在请求 2 请求成功 3 正在展示
    private int isLoadStatue = 0;

    public InteractionAdManager(Activity context) {
        super(context, Constants.AD_TYPE_INTERACTION);
    }

    public void requestInteractAD(String posId, InteractionBean interactionBean, EventChannel.EventSink eventSink) {
        if (!isSDKInit(TAG)) {
            return;
        }

        if (isLoadStatue == 1 || isLoadStatue == 3) {
            YFLog.high("requestInteractAD is loading or show");
            return;
        }

        if (easyInterstitial != null) {
            destroy();
        }
        easyInterstitial = new YFAdInterstitialAds(activity, new YFInterstitialListener() {
            @Override
            public void onAdSuccess() {
                isLoadStatue = 2;
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdSuccess");
                    if (InitUtils.isEpsOpen()) {
                        jsonObject.put(Constants.KEY_ECPM, easyInterstitial.getEcpm() + "");
                    }
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                if (interactionBean.isLoadAndShow()) {
                    showAd(activity);
                }
            }

            @Override
            public void onAdExposure() {
                isLoadStatue = 3;
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdShow");
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }

            @Override
            public void onAdClicked() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdClicked");
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }

            @Override
            public void onAdClosed() {
                FLog.i(TAG, "onAdClosed");
                isLoadStatue = 0;
                callAdClose();
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdClosed");
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                destroy();
            }

            @Override
            public void onAdFailed(YFAdError yfAdError) {
                isLoadStatue = 0;
                FLog.e(TAG, "onFailed, requestId: " + yfAdError.code + ", errMsg: " + yfAdError.msg);
                callAdFail(yfAdError.msg);
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onFailed");
                    jsonObject.put(Constants.KEY_ERROR, yfAdError.msg);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        });
        easyInterstitial.loadOnly(posId);
    }

    public void destroy() {
        if (easyInterstitial != null) {
            easyInterstitial.destroy();
        }
    }

    public void showAd(Activity activity) {
        YFLog.high("showAd isLoadStatue " + isLoadStatue);
        if (isLoadStatue == 2 && easyInterstitial != null && activity != null) {
            easyInterstitial.showAds(activity);
        }
    }

}
